@@ -1,5 +1,5 @@
 /*
-Copyright (c) 2003, 2004 by Juliusz Chroboczek
+Copyright (c) 2003-2006 by Juliusz Chroboczek
 
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
@@ -20,9 +20,22 @@ OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 THE SOFTWARE.
 */
 
+/* A larger chunk size gets you better I/O throughput, at the cost of
+   higer memory usage.  We assume you've got plenty of memory if you've
+   got 64-bit longs. */
+
 #ifndef CHUNK_SIZE
+#ifdef ULONG_MAX
+#if ULONG_MAX > 4294967295UL
+#define CHUNK_SIZE (8 * 1024)
+#else
 #define CHUNK_SIZE (4 * 1024)
 #endif
+#else
+#warn "ULONG_MAX not defined -- using 4kB chunks"
+#define CHUNK_SIZE (4 * 1024)
+#endif
+#endif
 
 #define CHUNKS(bytes) ((bytes) / CHUNK_SIZE)
 
@@ -34,5 +47,6 @@ void initChunks(void);
 void *get_chunk(void) ATTRIBUTE ((malloc));
 void *maybe_get_chunk(void) ATTRIBUTE ((malloc));
 
-void dispose_chunk(void*);
+void dispose_chunk(void *chunk);
 void free_chunk_arenas(void);
+int totalChunkArenaSize(void);
