@@ -1,5 +1,5 @@
 /*
-Copyright (c) 2003, 2004 by Juliusz Chroboczek
+Copyright (c) 2003-2006 by Juliusz Chroboczek
 
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
@@ -29,6 +29,7 @@ typedef struct _HTTPCondition {
 } HTTPConditionRec, *HTTPConditionPtr;
 
 typedef struct _HTTPRequest {
+    int flags;
     struct _HTTPConnection *connection;
     ObjectPtr object;
     int method;
@@ -37,12 +38,8 @@ typedef struct _HTTPRequest {
     CacheControlRec cache_control;
     HTTPConditionPtr condition;
     AtomPtr via;
-    int persistent;
-    int wait_continue;
+    struct _ConditionHandler *chandler;
     ObjectPtr can_mutate;
-    ObjectHandlerPtr ohandler;
-    int requested;
-    int force_error;
     int error_code;
     struct _Atom *error_message;
     struct _Atom *error_headers;
@@ -52,6 +49,13 @@ typedef struct _HTTPRequest {
     struct _HTTPRequest *next;
 } HTTPRequestRec, *HTTPRequestPtr;
 
+/* request->flags */
+#define REQUEST_PERSISTENT 1
+#define REQUEST_REQUESTED 2
+#define REQUEST_WAIT_CONTINUE 4
+#define REQUEST_FORCE_ERROR 8
+#define REQUEST_PIPELINED 16
+
 typedef struct _HTTPConnection {
     int flags;
     int fd;
@@ -62,6 +66,7 @@ typedef struct _HTTPConnection {
     HTTPRequestPtr request_last;
     int serviced;
     int version;
+    int time;
     TimeEventHandlerPtr timeout;
     int te;
     char *reqbuf;
@@ -81,6 +86,8 @@ typedef struct _HTTPConnection {
 #define CONN_READER 1
 #define CONN_WRITER 2
 #define CONN_SIDE_READER 4
+#define CONN_BIGBUF 8
+#define CONN_BIGREQBUF 16
 
 /* request->method */
 #define METHOD_UNKNOWN -1
@@ -107,14 +114,18 @@ typedef struct _HTTPConnection {
 /* connection->connecting */
 #define CONNECTING_DNS 1
 #define CONNECTING_CONNECT 2
+#define CONNECTING_SOCKS 3
 
 /* the results of a conditional request.  200, 304 and 412. */
 #define CONDITION_MATCH 0
 #define CONDITION_NOT_MODIFIED 1
 #define CONDITION_FAILED 2
 
+extern int disableProxy;
 extern AtomPtr proxyName;
 extern int proxyPort;
+extern int clientTimeout, serverTimeout, serverIdleTimeout;
+extern int bigBufferSize;
 extern AtomPtr proxyAddress;
 extern int proxyOffline;
 extern int relaxTransparency;
@@ -127,6 +138,8 @@ extern IntListPtr allowedPorts;
 extern IntListPtr tunnelAllowedPorts;
 extern int expectContinue;
 extern AtomPtr atom100Continue;
+extern int disableVia;
+extern int dontTrustVaryETag;
 
 void preinitHttp(void);
 void initHttp(void);
@@ -141,13 +154,22 @@ int htmlString(char *buf, int n, int len, char *s, int slen);
 void htmlPrint(FILE *out, char *s, int slen);
 HTTPConnectionPtr httpMakeConnection(void);
 void httpDestroyConnection(HTTPConnectionPtr connection);
+void httpConnectionDestroyBuf(HTTPConnectionPtr connection);
+void httpConnectionDestroyReqbuf(HTTPConnectionPtr connection);
 HTTPRequestPtr httpMakeRequest(void);
 void httpDestroyRequest(HTTPRequestPtr request);
 void httpQueueRequest(HTTPConnectionPtr, HTTPRequestPtr);
 HTTPRequestPtr httpDequeueRequest(HTTPConnectionPtr connection);
+int httpConnectionBigify(HTTPConnectionPtr);
+int httpConnectionBigifyReqbuf(HTTPConnectionPtr);
+int httpConnectionUnbigify(HTTPConnectionPtr);
+int httpConnectionUnbigifyReqbuf(HTTPConnectionPtr);
 HTTPConditionPtr httpMakeCondition(void);
 void httpDestroyCondition(HTTPConditionPtr condition);
 int httpCondition(ObjectPtr, HTTPConditionPtr);
 int httpWriteErrorHeaders(char *buf, int size, int offset, int do_body,
                           int code, AtomPtr message, int close, AtomPtr,
                           char *url, int url_len, char *etag);
+AtomListPtr urlDecode(char*, int);
+void httpTweakCachability(ObjectPtr);
+int httpHeaderMatch(AtomPtr header, AtomPtr headers1, AtomPtr headers2);
