@@ -1,3 +1,7 @@
+#ifndef _GNU_SOURCE
+#define _GNU_SOURCE
+#endif
+
 #include <stdlib.h>
 
 #if defined __STDC_VERSION__ && __STDC_VERSION__ >= 199901L
